@@ -1,15 +1,15 @@
-import logging
-from Products.CMFCore.utils import getToolByName
-
-from zope.component import getAllUtilitiesRegisteredFor
-from zope.component import queryUtility
-from plone.contentrules.engine.interfaces import IRuleStorage
-from plone.contentrules.engine.assignments import \
-    check_rules_with_dotted_name_moved
-
+# -*- coding: utf-8 -*-
 from plone.app.upgrade.utils import loadMigrationProfile
 from plone.app.upgrade.utils import unregisterSteps
 from plone.app.upgrade.v43.alphas import upgradeTinyMCEAgain
+from plone.contentrules.engine.assignments import check_rules_with_dotted_name_moved  # noqa E501
+from plone.contentrules.engine.interfaces import IRuleStorage
+from Products.CMFCore.utils import getToolByName
+from zope.component import getAllUtilitiesRegisteredFor
+from zope.component import queryUtility
+
+import logging
+
 
 # We had our own version of this, but it was just a copy.  We keep a
 # reference here to avoid breakage if someone imports it.
@@ -49,8 +49,9 @@ def addDefaultPlonePasswordPolicy(context):
 
 
 def addShowInactiveCriteria(context):
-    qi = getToolByName(context, 'portal_quickinstaller')
-    qi.upgradeProduct('plone.app.querystring')
+    qi = getToolByName(context, 'portal_quickinstaller', None)
+    if qi is not None:
+        qi.upgradeProduct('plone.app.querystring')
 
 
 def improveSyndication(context):
@@ -147,11 +148,6 @@ def markProductsInstalledForUninstallableProfiles(context):
     'plone.app.intid',
     'plone.app.referenceablebehavior',
     'plone.app.relationfield',
-    'plone.app.upgrade.v25',
-    'plone.app.upgrade.v30',
-    'plone.app.upgrade.v31',
-    'plone.app.upgrade.v32',
-    'plone.app.upgrade.v33',
     'plone.app.upgrade.v40',
     'plone.app.upgrade.v41',
     'plone.app.upgrade.v42',
@@ -164,7 +160,9 @@ def markProductsInstalledForUninstallableProfiles(context):
     """
     from Products.CMFPlone.interfaces import INonInstallable
     setup = context
-    qi = getToolByName(context, 'portal_quickinstaller')
+    qi = getToolByName(context, 'portal_quickinstaller', None)
+    if qi is None:
+        return
     # Get list of profiles that are marked as not installable.
     profile_ids = []
     utils = getAllUtilitiesRegisteredFor(INonInstallable)
@@ -194,7 +192,7 @@ def markProductsInstalledForUninstallableProfiles(context):
         qi.notifyInstalled(
             product_id,
             locked=False,
-            logmsg="Marked as installed by plone.app.upgrade",
+            logmsg='Marked as installed by plone.app.upgrade',
             settings={},
             installedversion=version,
             status='installed',
@@ -221,7 +219,9 @@ def cleanupUninstalledProducts(context):
     GS too.
     """
     setup = context
-    qi = getToolByName(context, 'portal_quickinstaller')
+    qi = getToolByName(context, 'portal_quickinstaller', None)
+    if qi is None:
+        return
     for prod in qi.objectValues():
         if prod.isInstalled():
             continue
@@ -272,7 +272,10 @@ def removeFakeKupu(context):
         tool = getToolByName(portal, tool_id, None)
         if tool is None:
             continue
-        resources = tool.getResourcesDict()
+        try:
+            resources = tool.getResourcesDict()
+        except AttributeError:
+            continue
         for resource_id, resource in resources.items():
             expression = resource.getExpression()
             if expression.startswith(bad_expr):
@@ -281,7 +284,7 @@ def removeFakeKupu(context):
             elif kupu_id in expression:
                 # We are tempted to remove this, but who knows if the
                 # expression is something like this:
-                # "'kupu_library_tool' not in portal"
+                # ''kupu_library_tool' not in portal'
                 logger.warn('%s in %s has %s in expression. You probably '
                             'want to change the expression or remove the '
                             'resource.', resource_id, tool_id, kupu_id)
@@ -291,6 +294,12 @@ def removeFakeKupu(context):
         # Note that this does nothing when the configlet is not there.
         control_panel.unregisterConfiglet('kupu')
         logger.info('Removed kupu control panel configlet.')
+
+    # The function was too complex, so we split it.
+    _remove_kupu_from_props(portal)
+
+
+def _remove_kupu_from_props(portal):
     # Remove editor from site_properties.
     pprops = getToolByName(portal, 'portal_properties', None)
     available_editors = []
@@ -315,7 +324,7 @@ def removeFakeKupu(context):
     # Remove from portal_memberdata.  Note that you can use
     # collective.setdefaulteditor if you want more options, like
     # updating the chosen editor for all existing members.
-    member_data = getToolByName(context, 'portal_memberdata')
+    member_data = getToolByName(portal, 'portal_memberdata')
     if member_data.getProperty('wysiwyg_editor') == 'Kupu':
         member_data._updateProperty('wysiwyg_editor', '')
         logger.info('Changed new member wysiwyg_editor to site default.')
@@ -326,7 +335,8 @@ def addSortOnProperty(context):
 
     The default value of this field is relevance.
     """
-    site_properties = getToolByName(context, 'portal_properties').site_properties
+    site_properties = getToolByName(
+        context, 'portal_properties').site_properties
     if not site_properties.hasProperty('sort_on'):
         if 'sort_on' in site_properties.__dict__:
             # fix bug if 4.3.1 pending has been tested
@@ -334,32 +344,3 @@ def addSortOnProperty(context):
         site_properties.manage_addProperty('sort_on', 'relevance', 'string')
         logger.log(logging.INFO,
                    "Added 'sort_on' property to site_properties.")
-
-
-def fix_double_smaxage(context):
-    """Fix caching definition.
-
-    plone.resource.maxage has title and description from shared maxage.
-    See https://github.com/plone/Products.CMFPlone/issues/1989
-    """
-    from plone.registry.record import Record
-    from plone.registry import FieldRef
-    from plone.registry.interfaces import IRegistry
-    from zope.component import getUtility
-    registry = getUtility(IRegistry)
-    # If these three registry records are not defined,
-    # we do no fix.
-    maxage = 'plone.app.caching.strongCaching.plone.resource.maxage'
-    def_maxage = 'plone.app.caching.strongCaching.maxage'
-    def_smaxage = 'plone.app.caching.strongCaching.smaxage'
-    for name in (maxage, def_maxage, def_smaxage):
-        if name not in registry:
-            return
-    field = registry.records[maxage].field
-    if isinstance(field, FieldRef) and field.recordName != def_smaxage:
-        # no fix needed
-        return
-    field_ref = FieldRef(def_maxage, registry.records[def_maxage].field)
-    old_value = registry[maxage]
-    registry.records[maxage] = Record(field_ref, old_value)
-    logger.info('Fixed {0} to refer to {1}.'.format(maxage, def_maxage))
